@@ -99,9 +99,11 @@ impl<T> RCell<T> {
 
     // idea borrowed from crossbeam SeqLock
     fn sharded_mutex(&self) -> &'static RawMutex {
-        const LEN: usize = 97;
-        static LOCKS: [RawMutex; LEN] = [RawMutex::INIT; LEN];
-        &LOCKS[self as *const Self as usize % LEN]
+        const LEN: usize = 127;
+        #[repr(align(128))] // cache line aligned
+        struct Locks([RawMutex; LEN]);
+        static LOCKS: Locks = Locks([RawMutex::INIT; LEN]);
+        &LOCKS.0[self as *const Self as usize % LEN]
     }
 
     // Acquire a global sharded lock with unlock on drop semantics
@@ -200,7 +202,7 @@ impl<T> Clone for ArcState<T> {
 
 #[cfg(test)]
 mod tests {
-    use crate::RCell;
+    use crate::{RCell, Replace};
     use std::sync::Arc;
 
     #[test]
@@ -260,4 +262,26 @@ mod tests {
         rcell.remove();
         assert_eq!(rcell.request(), None);
     }
+
+    #[test]
+    fn replace_arc() {
+        let rcell = RCell::default();
+        assert!(!rcell.retained());
+        rcell.replace(Arc::new("foobar"));
+        assert_eq!(*rcell.request().unwrap(), "foobar");
+        rcell.remove();
+        assert_eq!(rcell.request(), None);
+    }
+
+    #[test]
+    fn replace_weak() {
+        let arc = Arc::new("foobar");
+        let rcell = RCell::default();
+        assert!(!rcell.retained());
+        rcell.replace(Arc::downgrade(&arc));
+        assert_eq!(*rcell.request().unwrap(), "foobar");
+        rcell.remove();
+        assert_eq!(rcell.request(), None);
+    }
+
 }
